==> atomikos-util-3.8.0-sources.jar: com/atomikos/finitestates/FSMTransitionEvent.java <==
/**
 * Copyright (C) 2000-2010 Atomikos <info@atomikos.com>
 *
 * This code ("Atomikos TransactionsEssentials"), by itself,
 * is being distributed under the
 * Apache License, Version 2.0 ("License"), a copy of which may be found at
 * http://www.atomikos.com/licenses/apache-license-2.0.txt .
 * You may not use this file except in compliance with the License.
 *
 * While the License grants certain patent license rights,
 * those patent license rights only extend to the use of
 * Atomikos TransactionsEssentials by itself.
 *
 * This code (Atomikos TransactionsEssentials) contains certain interfaces
 * in package (namespace) com.atomikos.icatch
 * (including com.atomikos.icatch.Participant) which, if implemented, may
 * infringe one or more patents held by Atomikos.
 * It should be appreciated that you may NOT implement such interfaces;
 * licensing to implement these interfaces must be obtained separately from Atomikos.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 */

package com.atomikos.finitestates;

import java.util.EventObject;

/**
*
*
*Events signalling a transition of a FSM.
*/
public class FSMTransitionEvent extends EventObject{

	private static final long serialVersionUID = 7629493293234798149L;

	protected Object from,to;

	public FSMTransitionEvent(Object source,Object fromState,Object toState){
		super(source);
		from=fromState;
		to=toState;
	}
	/**
	*The state that was left.
	*/
	public Object fromState(){
		return from;
	}

	/**
	*The state that was moved to.
	*/
	public Object toState(){
		return to;
	}
}

==> atomikos-util-3.9.1-sources.jar: com/atomikos/finitestates/FSMTransitionEvent.java <==
/**
 * Copyright (C) 2000-2010 Atomikos <info@atomikos.com>
 *
 * This code ("Atomikos TransactionsEssentials"), by itself,
 * is being distributed under the
 * Apache License, Version 2.0 ("License"), a copy of which may be found at
 * http://www.atomikos.com/licenses/apache-license-2.0.txt .
 * You may not use this file except in compliance with the License.
 *
 * While the License grants certain patent license rights,
 * those patent license rights only extend to the use of
 * Atomikos TransactionsEssentials by itself.
 *
 * This code (Atomikos TransactionsEssentials) contains certain interfaces
 * in package (namespace) com.atomikos.icatch
 * (including com.atomikos.icatch.Participant) which, if implemented, may
 * infringe one or more patents held by Atomikos.
 * It should be appreciated that you may NOT implement such interfaces;
 * licensing to implement these interfaces must be obtained separately from Atomikos.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 */

package com.atomikos.finitestates;

import java.util.EventObject;

public class FSMTransitionEvent<Status> extends EventObject{

	private static final long serialVersionUID = 7629493293234798149L;

	protected Status from,to;

	public FSMTransitionEvent(Object source,Status fromState,Status toState){
		super(source);
		from=fromState;
		to=toState;
	}
	
	public Status fromState(){
		return from;
	}

	public Status toState(){
		return to;
	}
}
